@@ -5,7 +5,8 @@
 <https://atlas.ripe.net/> probes using the UDM (User Defined
 Measurements) creation API.
 
-Authorization key is expected in $HOME/.atlas/auth or have to be
+Authorization key is expected in $HOME/.atlas/auth
+in the environment variable ATLASAUTH or have to be
 provided in the constructor's arguments.
 
 Stéphane Bortzmeyer <stephane+frama@bortzmeyer.org>
@@ -13,7 +14,7 @@ Stéphane Bortzmeyer <stephane+frama@bortzmeyer.org>
 """
 
 # WARNING: if you modify it here, also change setup.py https://packaging.python.org/guides/single-sourcing-package-version/#single-sourcing-the-version
-VERSION = '1.1.9'
+VERSION = '1.1.10'
 
 import os
 import json
@@ -328,14 +329,19 @@ class Measurement():
         
         # TODO: when creating a dummy measurement, a key may not be necessary if the measurement is public
         if not key:
-            if not os.path.exists(authfile):
-                raise AuthFileNotFound("Authentication file %s not found" % authfile)
-            auth = open(authfile)
-            key = auth.readline()
-            if key is None or key == "":
-                raise AuthFileEmpty("Authentication file %s empty or missing a end-of-line at the end" % authfile)
-            key = key.rstrip('\n')
-            auth.close()
+            if os.environ.get("ATLASAUTH"):
+                # use envvar ATLASAUTH for the key
+                key = os.environ.get("ATLASAUTH")
+            else:
+                # use file for key if envvar ATLASAUTH isn't set
+                if not os.path.exists(authfile):
+                    raise AuthFileNotFound("Authentication file %s not found" % authfile)
+                auth = open(authfile)
+                key = auth.readline()
+                if key is None or key == "":
+                    raise AuthFileEmpty("Authentication file %s empty or missing a end-of-line at the end" % authfile)
+                key = key.rstrip('\n')
+                auth.close()
 
         self.url = base_url + "/?key=%s" % key
         self.url_probes = base_url + "/%s/?fields=probes,status" + "&key=%s" % key
